@@ -1,32 +1,38 @@
+# Description: A list of adjectives and animals to use in the Ubuntu Namer
+# We aim to keep these names non-offensive, non-derogatory, and short-ish.
+
 ubuntu_names = {
     "a": {
         "adjectives": [
             "Able",
             "Acute",
             "Adventurous",
-            "Agile",
             "Aggravated",
-            "Alcoholic",
-            "Alliterating",
-            "Amok",
-            "Angelic",
-            "Antsy",
+            "Agile",
             "Amazing",
             "Ambling",
-            "Amenable",
             "Amicable",
             "Anarchic",
-            "Annoying",
-            "Antidisestablishmentarian",
             "Androgynous",
-            "Archaic",
-            "Arty",
-            "Atomic",
-            "Atrophying",
-            "Awesome",
-            "Aware",
-            "Aztec",
+            "Angelic",
+            "Annoying",
             "Antlered",
+            "Antsy",
+            "Archaic",
+            "Aromatic",
+            "Artsy",
+            "Astonishing",
+            "Astounding",
+            "Astute",
+            "Athletic",
+            "Atomic",
+            "Attractive",
+            "Austere",
+            "Avid",
+            "Avuncular",
+            "Aware",
+            "Awesome",
+            "Awkward",
         ],
         "animals": [
             "Aal",
@@ -34,8 +40,6 @@ ubuntu_names = {
             "Affenpinscher",
             "Agama",
             "Albatross",
-            "Alebrije",
-            "Alien",
             "Alligator",
             "Alpaca",
             "Amoeba",
@@ -56,25 +60,38 @@ ubuntu_names = {
     },
     "b": {
         "adjectives": [
-            "Ballsy",
-            "Batty",
+            "Baffling",
+            "Bamboozling",
             "Barking",
+            "Bashful",
+            "Batty",
+            "Bawdy",
+            "Beaming",
+            "Beautiful",
+            "Befuddled",
+            "Beguiling",
             "Belching",
             "Bellicose",
+            "Belligerent",
+            "Benevolent",
+            "Bent",
             "Bewildered",
+            "Bewitched",
+            "Big",
             "Blustering",
             "Boggling",
             "Boisterous",
-            "Bonkers",
             "Bounding",
             "Brainy",
             "Brave",
             "Brazen",
             "Breezy",
-            "Brilliant",
             "Bright",
+            "Brilliant",
             "Bumpy",
+            "Bustling",
             "Busy",
+            "Buzzy",
         ],
         "animals": [
             "Baboon",
@@ -88,13 +105,13 @@ ubuntu_names = {
             "Bee",
             "Beetle",
             "Bison",
-            "Bitch",
             "Bittern",
             "Blackbird",
             "Blowfish",
             "Bluejay",
             "Bobcat",
             "Bonobo",
+            "Booby",
             "Bothrop",
             "Bowerbird",
             "Buck",
@@ -105,46 +122,44 @@ ubuntu_names = {
     "c": {
         "adjectives": [
             "Calculating",
-            "Callous",
             "Campy",
             "Canny",
-            "Canonical",
             "Careful",
             "Cavalier",
-            "Celebrating",
+            "Celebrity",
+            "Cerebral",
             "Charming",
             "Cheeky",
             "Cheerful",
             "Cheesy",
             "Chirping",
-            "Chocolate",
-            "Chronic",
+            "Chonky",
             "Chummy",
             "Clever",
             "Clumsy",
             "Colonel",
-            "Constipated",
             "Cool",
+            "Cosmic",
             "Courageous",
-            "Crabby",
+            "Coy",
             "Crafty",
             "Cranky",
-            "Crazy",
             "Crooked",
-            "Cruising",
             "Cuddly",
-            "Culpable",
             "Cunning",
-            "Cute",
+            "Curious",
             "Curt",
-            "Cosmic",
+            "Cute",
+            "Cynical",
         ],
         "animals": [
             "Camel",
+            "Canine",
             "Capybara",
             "Caracal",
             "Cardinal",
             "Caribou",
+            "Carnivore",
             "Cassowary",
             "Cat",
             "Caterpillar",
@@ -171,42 +186,64 @@ ubuntu_names = {
             "Crane",
             "Crocodile",
             "Crow",
+            "Cuckoo",
+            "Curlew",
+            "Cuscus",
             "Cuttlefish",
+            "Cygnet",
         ],
     },
     "d": {
         "adjectives": [
+            "Daffy",
+            "Dainty",
+            "Dandy",
             "Dapper",
-            "Dangerous",
             "Daring",
             "Dastardly",
             "Daunting",
             "Dazzling",
             "Defiant",
             "Diligent",
-            "Disaffected",
+            "Diplomatic",
+            "Disarming",
+            "Disco",
+            "Discreet",
             "Disorderly",
+            "Disruptive",
             "Dogmatic",
+            "Doting",
+            "Doubtful",
+            "Dramatic",
             "Dreamy",
+            "Droll",
             "Drowsy",
-            "Durable",
+            "Drunk",
+            "Drunken",
+            "Dull",
+            "Dumb",
+            "Dumpy",
             "Dutiful",
+            "Dynamic",
         ],
         "animals": [
+            "Dachshund",
+            "Dalmatian",
+            "Damselfly",
             "Deer",
-            "Devil",
             "Dingo",
+            "Dinosaur",
             "Diplodocus",
             "Dodo",
+            "Dogfish",
             "Doe",
             "Dog",
             "Dolphin",
             "Donkey",
             "Dormouse",
             "Dove",
-            "Dragon",
             "Drake",
-            "Dryad",
+            "Dragonfly",
             "Duck",
             "Dugong",
             "Dungbeetle",
@@ -216,32 +253,42 @@ ubuntu_names = {
     "e": {
         "adjectives": [
             "Eager",
-            "Early",
             "Earnest",
             "Easy",
             "Eccentric",
             "Eclectic",
             "Edgy",
-            "Eel",
-            "Eerie",
             "Effervescent",
+            "Elated",
             "Electric",
-            "Eminent",
             "Elegant",
             "Elite",
             "Eloquent",
-            "Embraceable",
+            "Elusive",
+            "Eminent",
+            "Emotional",
+            "Empathetic",
+            "Enchanting",
+            "Encouraging",
+            "Endearing",
+            "Energetic",
+            "Engaging",
+            "Enigmatic",
             "Enlightened",
-            "Enoumous",
+            "Enormous",
+            "Enthusiastic",
+            "Enticing",
+            "Envious",
+            "Ephemeral",
+            "Epic",
+            "Epicurean",
             "Erratic",
             "Euphoric",
             "Evangelizing",
             "Exquisite",
             "Extrovert",
-            "Eked",
         ],
         "animals": [
-            "Eagle",
             "Eagle",
             "Earthworm",
             "Earwig",
@@ -260,33 +307,30 @@ ubuntu_names = {
     },
     "f": {
         "adjectives": [
+            "Fabulous",
             "Fair",
-            "Fairies",
-            "Fanatical",
+            "Faithful",
+            "Fancy",
             "Fantastic",
             "Farsighted",
-            "Fatuous",
+            "Fast",
+            "Fearless",
             "Fecund",
             "Feisty",
-            "Festive",
             "Ferocious",
+            "Festive",
             "Fierce",
-            "Fiery",
-            "Fishy",
-            "Fitchew",
+            "Fiery" "Flaky",
             "Flamboyant",
-            "Flakey",
             "Flashy",
+            "Flawless",
+            "Fluffy",
             "Flippant",
-            "Flirty",
             "Fluent",
             "Flying",
             "Foxy",
             "Friendly",
             "Frisky",
-            "Froody",
-            "Fruity",
-            "Functional",
             "Funky",
             "Furious",
             "Furry",
@@ -296,7 +340,6 @@ ubuntu_names = {
             "Falcon",
             "Fawn",
             "Feline",
-            "Fenestrator",
             "Fenix",
             "Fennec",
             "Ferret",
@@ -313,61 +356,61 @@ ubuntu_names = {
             "Frog",
             "Fruitbat",
             "Fugu",
-            "Furbolg",
+            "Fulmar",
         ],
     },
     "g": {
         "adjectives": [
-            "Gaia",
             "Gallant",
             "Galloping",
-            "Gallus",
+            "Galvanizing",
             "Gargantuan",
-            "Gelatinous",
+            "Gaudy",
+            "Gentle",
             "Giddy",
-            "Genderqueer",
             "Giggling",
-            "Glad",
-            "Gleaming",
-            "Gnathonic",
-            "Gnathal",
-            "Gnomic",
-            "Gnostic",
-            "Gooey",
+            "Gleeful",
             "Glorious",
+            "Glowing",
+            "Gnarly",
+            "Gobsmacked",
             "Goofy",
-            "Gol",
             "Gorgeous",
             "Graceful",
             "Gracious",
+            "Grand",
+            "Grandiose",
+            "Grateful",
             "Great",
             "Greedy",
             "Gregarious",
+            "Grim",
+            "Grimacing",
             "Grinning",
             "Gritty",
-            "Grizzly",
+            "Groaning" "Grizzly",
             "Groovy",
             "Grumpy",
             "Gutsy",
         ],
         "animals": [
+            "Gadwall",
             "Galah",
             "Gannet",
             "Gappu",
             "Gator",
             "Gazelle",
             "Gecko",
-            "Gelding",
             "Gerbil",
-            "Ghost",
+            "Germ",
             "Gibbon",
+            "Gila",
             "Giraffe",
             "Gnarwhal",
             "Gnat",
             "Gnu",
             "Goat",
             "Gobbler",
-            "Goblin",
             "Goldfinch",
             "Goose",
             "Gopher",
@@ -376,144 +419,130 @@ ubuntu_names = {
             "Grebe",
             "Groundhog",
             "Grue",
-            "Gryphon",
             "Guanaco",
             "Gull",
             "Guppy",
-            "Gurk",
+            "Gyrfalcon",
         ],
     },
     "h": {
         "adjectives": [
             "Hairy",
+            "Half",
+            "Handsome",
             "Happy",
             "Hardy",
+            "Harmonious",
+            "Harried",
+            "Hasty",
             "Haughty",
+            "Hawkish",
             "Hazardous",
+            "Healthy",
+            "Healthy",
+            "Hearty",
+            "Heavenly",
+            "Heavy",
             "Helpful",
             "Helpless",
+            "Heroic",
             "Hilarious",
             "Hippy",
+            "Hirsute",
+            "Hissing",
             "Hoary",
             "Holy",
+            "Honest",
             "Hoopy",
+            "Hopeful",
             "Hopping",
             "Horned",
-            "Horny",
-            "Horrible",
-            "Hot",
             "Howling",
             "Huge",
             "Humble",
-            "Humourous",
-            "Humpin",
+            "Humorous",
             "Hungry",
-            "Hyperactive",
         ],
         "animals": [
+            "Haddock",
+            "Hagfish",
+            "Hake",
+            "Halibut",
+            "Hammerhead",
             "Hamster",
             "Hare",
             "Harrier",
             "Hartebeest",
             "Hawk",
             "Hedgehog",
-            "Heffalump",
             "Hen",
             "Heron",
-            "Hippo(potamus)",
+            "Herring",
+            "Hippo",
+            "Hog",
             "Hoopoe",
+            "Hornbill",
             "Hornet",
             "Horse",
-            "Horus",
-            "Hounddog",
+            "Hound",
             "Human",
             "Hummingbird",
             "Humpback",
             "Husky",
+            "Hyacinth",
+            "Hydra",
             "Hyena",
-            "Hypnotoad",
         ],
     },
     "i": {
         "adjectives": [
-            "Icky",
-            "Icy",
+            "Idiosyncratic",
             "Idyllic",
-            "Iffy",
-            "Igneous",
-            "Ignited",
             "Illuminating",
             "Illustrious",
-            "Immodest",
+            "Illustrious",
+            "Imaginative",
+            "Immaculate",
+            "Immaterial",
+            "Immense",
+            "Imminent",
             "Immortal",
             "Impish",
             "Impressive",
-            "Incendiary",
             "Incomparable",
-            "Inconceivable",
-            "Incontinent",
             "Incredible",
-            "Incriminatory",
-            "Indefatigable",
             "Indelible",
             "Industrious",
             "Inebriated",
             "Ineffable",
             "Inescapable",
-            "Inestimable",
-            "Inevitable",
             "Inexorable",
             "Infallible",
-            "Inflammatory",
-            "Inflationary",
             "Ingenious",
             "Ingratiating",
-            "Initiatory",
-            "Inky",
             "Innocent",
             "Innovatory",
             "Inquisitive",
-            "Insanitary",
             "Insatiable",
             "Inscrutable",
             "Insightful",
-            "Insolent",
-            "Insouciant",
             "Inspirational",
             "Inspired",
-            "Insurgent",
             "Intelligent",
-            "Interagency",
-            "Intercalary",
-            "Intercessory",
-            "Intercity",
-            "Intermediary",
-            "Interstellar",
-            "Intervarsity",
-            "Intimate",
             "Intimidated",
             "Intrepid",
-            "Investigatory",
-            "Irate",
             "Iridescent",
-            "Irie",
-            "Irksome",
-            "Irrefutable",
             "Itchy",
         ],
         "animals": [
             "Ibex",
             "Ibis",
-            "Ichabodcraniosaurus",
             "Ichthyosaur",
             "Iguana",
-            "Iguana",
-            "Iguana",
             "Iguanodon",
             "Iguanosaurus",
             "Iliosuchus",
             "Ilokelesia",
-            "Imp",
             "Impala",
             "Incisivosaurus",
             "Indosaurus",
@@ -523,7 +552,6 @@ ubuntu_names = {
             "Inkanyamba",
             "Inosaurus",
             "Insect",
-            "Irritator",
             "Irukandji",
             "Isanosaurus",
             "Ischisaurus",
@@ -533,99 +561,58 @@ ubuntu_names = {
             "Issasaurus",
             "Itemirus",
             "Iuticosaurus",
-            "Ivory",
         ],
     },
     "j": {
         "adjectives": [
             "Jabbering",
             "Jaded",
-            "Jaundice",
             "Jaunty",
             "Jazzy",
             "Jealous",
-            "Jiggly",
-            "Jinchira",
-            "Jittery",
-            "Jiving",
-            "Jocular",
-            "Jocund",
-            "Jodeling",
+            "Jiggly" "Jocular",
             "Jogging",
             "Jolly",
-            "Jolted",
-            "Jolty",
             "Jousting",
             "Jovial",
             "Joyous",
             "Jubilant",
             "Judicious",
             "Juggling",
-            "Juicy",
-            "Jumbled",
             "Jumping",
-            "Jumpity",
             "Jumpy",
             "Jungle",
-            "Jungly",
             "Jurassic",
             "Juvenile",
         ],
         "animals": [
-            "Jabberwock",
             "Jacana",
             "Jackal",
             "Jackalope",
             "Jackass",
             "Jackrabbit",
-            "Jackrabbit",
             "Jaguar",
             "Javelina",
             "Jay",
-            "Jaybird",
             "Jellyfish",
-            "Jentink's",
             "Jerboa",
             "Joey",
-            "Jubata",
             "Junco",
             "Junebug",
         ],
     },
     "k": {
         "adjectives": [
-            "Kafkaesque",
             "Kaleidoscopic",
-            "Kamikaze",
-            "Kanny",
             "Karmic",
-            "Katie",
-            "Kayoed",
-            "Keeking",
             "Keen",
-            "Keepable",
-            "Kempy",
-            "Khaki",
-            "Kick-ass",
             "Kicking",
-            "Kicky",
-            "Killer",
             "Kilted",
             "Kind",
-            "Kindhearted",
             "Kinetic",
-            "King-sized",
             "Kingly",
-            "Kissy",
             "Kitschy",
-            "Kleptomaniacal",
-            "Klutzy",
-            "Knavish",
             "Knightly",
-            "Knotty",
-            "Kooky",
-            "Kurt",
-            "Kvetching",
         ],
         "animals": [
             "Kakapo",
@@ -635,17 +622,14 @@ ubuntu_names = {
             "Kea",
             "Kelpie",
             "Kestrel",
-            "Kid",
             "Killdeer",
             "Kingfisher",
             "Kinkajou",
             "Kite",
             "Kitten",
-            "Kittie",
             "Kittiwake",
             "Kittyhawk",
             "Kiwi",
-            "Knight",
             "Koala",
             "Kodiak",
             "Kodkod",
@@ -656,48 +640,28 @@ ubuntu_names = {
             "Kookaburra",
             "Kouprey",
             "Kowari",
-            "Kraut",
-            "Krocodile",
             "Kudu",
         ],
     },
     "l": {
         "adjectives": [
             "Lampooning",
-            "Languid",
-            "Lascivious",
             "Laudable",
-            "Laughable",
             "Laughing",
-            "Lazy",
-            "Leaky",
             "Leal",
             "Leaping",
             "Leapy",
-            "Leftist",
-            "Lethal",
-            "Liberal",
-            "Limp",
             "Lingual",
-            "Listless",
             "Lithe",
-            "Litigious",
             "Lively",
             "Lofty",
-            "Lonely",
             "Longhorn",
-            "Loopy",
             "Loquacious",
-            "Lordly",
             "Lovely",
             "Lucid",
             "Lucky",
-            "Lugubrious",
-            "Luminiferous",
             "Luminous",
-            "Lurid",
-            "Luscious",
-            "Lusty",
+            "Lunar",
         ],
         "animals": [
             "Labrador",
@@ -726,71 +690,37 @@ ubuntu_names = {
             "Lorax",
             "Loris",
             "Louse",
-            "lycaon",
             "Lynx",
+            "Lycaon",
         ],
     },
     "m": {
         "adjectives": [
-            "Macular",
-            "Mad",
             "Magical",
             "Magistical",
             "Magnanimous",
             "Magnetic",
             "Magnificent",
-            "Maieutic",
             "Majestic",
-            "Majim",
-            "Majuscul",
-            "Malapert",
-            "Malicious",
-            "Malodorous",
-            "Malty",
             "Mammoth",
-            "Mangy",
-            "Manic",
-            "Marauding",
             "Marvelous",
             "Massive",
             "Masterful",
-            "Maudlin",
             "Maverick",
-            "Mazarine",
             "Meandering",
             "Measured",
             "Meaty",
             "Melancholic",
-            "Melic",
-            "Melliferous",
             "Mellifluous",
             "Mellow",
             "Melodic",
-            "Melodious",
             "Memorable",
-            "Menacing",
-            "Menstrual",
-            "Mental",
-            "Mercantile",
-            "Mercenary",
-            "Merciful",
-            "Merciless",
             "Mercurial",
-            "Meridian",
             "Merry",
-            "Mesmeric",
-            "Metallic",
-            "Methodic",
             "Meticulous",
-            "Metric",
-            "Mettled",
-            "Mickle",
             "Mighty",
-            "Mild",
-            "Militant",
             "Mindful",
             "Mini",
-            "Minimalist",
             "Minty",
             "Miraculous",
             "Mischievous",
@@ -799,34 +729,24 @@ ubuntu_names = {
             "Modest",
             "Modish",
             "Momentous",
-            "Monadic",
             "Monastic",
             "Monty",
-            "Moonlight",
             "Moral",
-            "Mordant",
-            "Moxious",
-            "Murphy",
-            "Muscled",
-            "Mushy",
+            "Muscular",
             "Musical",
             "Musky",
-            "Muttering",
-            "Myriad",
             "Mysterious",
             "Mystic",
-            "Mystical",
             "Mythical",
         ],
         "animals": [
             "Macaque",
             "Macaw",
             "Macropod",
-            "Maggots",
+            "Maggot",
             "Magpie",
             "Mallard",
             "Mammoth",
-            "Man",
             "Manatee",
             "Mandrill",
             "Manta",
@@ -839,6 +759,7 @@ ubuntu_names = {
             "Mastiff",
             "Meadowlark",
             "Meerkat",
+            "Meglodon",
             "Millipede",
             "Mink",
             "Minnow",
@@ -868,39 +789,37 @@ ubuntu_names = {
     },
     "n": {
         "adjectives": [
+            "Naked",
+            "Narrow",
             "Nano",
-            "Nasty",
-            "Natty",
             "Naughty",
-            "Nauseous",
-            "Necrotising",
-            "Nefarious",
+            "Nautical",
+            "New",
+            "Nice",
             "Nerdy",
             "Nested",
-            "Neurotic",
             "Nifty",
             "Nimble",
-            "Nippy",
             "Noble",
             "Nocturnal",
+            "Noisy",
             "Nomadic",
             "Normal",
-            "Normandic",
             "Nostalgic",
             "Novel",
-            "Null",
-            "Nutritious",
+            "Nuclear",
+            "Numb",
         ],
         "animals": [
             "Naiad",
             "Narwhal",
+            "Natterjack",
+            "Nautilus",
             "Newt",
-            "Nicholine",
-            "Nightelf",
             "Nightingale",
             "Nightjar",
-            "Ninf",
             "Numbat",
+            "Nuthatch",
             "Nutria",
             "Nymph",
         ],
@@ -909,42 +828,27 @@ ubuntu_names = {
         "adjectives": [
             "Obedient",
             "Oblivious",
-            "Obnoxious",
             "Obsequious",
             "Observing",
-            "Obstreperous",
             "Obtuse",
             "Obverse",
-            "Obvious",
-            "Occult",
-            "Octal",
-            "Octennial",
             "Odd",
-            "Oily",
             "Okay",
-            "Omnific",
             "Omniscient",
             "Oneiric",
-            "Opportune",
             "Opportunistic",
             "Opulent",
             "Orderly",
             "Ordinary",
-            "Origamist",
-            "Ornery",
             "Orthodox",
-            "Orthogenic",
-            "Oscillating",
             "Ostentatious",
         ],
         "animals": [
             "Ocelot",
             "Octopus",
             "Okapi",
-            "Oompa-loompa",
             "Opossum",
             "Orangutan",
-            "Orc",
             "Orca",
             "Oriole",
             "Oryx",
@@ -958,55 +862,31 @@ ubuntu_names = {
     "p": {
         "adjectives": [
             "Pacific",
-            "Panacean",
-            "Parabolic",
-            "Paradisaic",
             "Paramount",
             "Passive",
             "Peachy",
-            "Pedantic",
             "Perceptive",
             "Perennial",
             "Perky",
             "Persistent",
             "Persnickety",
-            "Phantastic",
-            "Phantom",
             "Phat",
             "Philantropic",
             "Philosophical",
-            "Phlegmatic",
-            "Phlegmatic",
-            "Phobic",
-            "Phooka",
             "Photogenic",
-            "Pickled",
-            "Pimping",
             "Pink",
-            "Plastered",
-            "Plastic",
             "Playful",
-            "Plonky",
             "Plucky",
             "Plutonic",
             "Poetic",
-            "Pointy",
-            "Pokey",
             "Polished",
-            "Polyplastic",
             "Posh",
             "Powerful",
-            "Powersaver",
             "Pragmatic",
             "Prancing",
-            "Precise",
             "Precocious",
-            "Predatory",
-            "Predictive",
-            "Predominate",
-            "Prestidigious",
+            "Prestigious",
             "Pretty",
-            "Priapic",
             "Prickly",
             "Prideful",
             "Prissy",
@@ -1014,15 +894,11 @@ ubuntu_names = {
             "Proactive",
             "Prolific",
             "Proud",
-            "Prowly",
+            "Prowling",
             "Prudent",
             "Psychedelic",
             "Psychic",
-            "Pulchritudinous",
             "Purring",
-            "Pyroclastic",
-            "Pyromaniac",
-            "Pyrotechnic",
         ],
         "animals": [
             "Pademelon",
@@ -1067,17 +943,17 @@ ubuntu_names = {
         "adjectives": [
             "Quaint",
             "Quaking",
+            "Qualified",
             "Quantal",
             "Quantum",
-            "Quarter",
-            "Queer",
-            "Querulous",
+            "Quasi",
             "Quick",
             "Quiet",
             "Quintessential",
             "Quirky",
             "Quivering",
             "Quixotic",
+            "Quizzical",
         ],
         "animals": [
             "Qantassaurus",
@@ -1092,49 +968,48 @@ ubuntu_names = {
     },
     "r": {
         "adjectives": [
-            "Rabid",
-            "Racey",
             "Racing",
             "Radiant",
             "Radical",
             "Rambunctious",
-            "Rampant",
-            "Rancid",
             "Randy",
             "Rapid",
             "Raring",
             "Rational",
-            "Raucous",
-            "Raunchy",
+            "Ravenous",
+            "Ravishing",
             "Reasonable",
             "Rebel",
-            "Rebellious",
             "Rednosed",
+            "Reformed",
+            "Regal",
+            "Relaxed",
+            "Relentless",
+            "Reliable",
+            "Relieved",
+            "Remarkable",
             "Reminiscent",
-            "Resonant",
-            "Rhapsy",
+            "Rhetorical",
+            "Rhythmic",
             "Ribald",
             "Rich",
-            "Risky",
-            "Roasted",
+            "Rival",
+            "Roaring",
             "Robust",
-            "Rolly",
             "Rowdy",
             "Rugged",
-            "Runcible",
-            "Ruthless",
         ],
         "animals": [
             "Rabbit",
             "Raccoon",
             "Raptor",
-            "Raptor",
             "Rat",
             "Ratel",
             "Rattlesnake",
             "Raven",
             "Redbird",
             "Reindeer",
+            "Reptile",
             "Rhea",
             "Rhino",
             "Ringtail",
@@ -1144,82 +1019,46 @@ ubuntu_names = {
             "Rook",
             "Rooster",
             "Rottweiler",
+            "Ruff",
         ],
     },
     "s": {
         "adjectives": [
-            "Saccate",
-            "Saccharine",
-            "Sagacious",
             "Sage",
             "Salivating",
-            "Salubrious",
             "Sanguine",
             "Sarcastic",
-            "Sardonic",
             "Sassy",
             "Saucy",
-            "Scary",
             "Scrawny",
-            "Screwy",
-            "Secretive",
-            "Selenographic",
-            "Selenomorphic",
             "Sentimental",
             "Serendipitous",
             "Serious",
             "Servile",
-            "Severe",
-            "Sharp",
-            "Shiny",
             "Shrewd",
-            "Silly",
-            "Skinny",
             "Slick",
             "Slim",
-            "Slimmy",
-            "Slinky",
-            "Slippery",
-            "Slippy",
-            "Smelly",
             "Smiling",
             "Smitten",
             "Smooth",
-            "Snappy",
             "Snazzy",
             "Sneaky",
             "Soaring",
-            "Solid",
             "Sophisticated",
             "Sound",
-            "Spastic",
-            "Special",
-            "Spectacular",
             "Speedy",
-            "Spicy",
-            "Spooky",
             "Spotty",
             "Sprightly",
-            "Spunky",
-            "Squidgy",
-            "Squirly",
             "Stalwart",
             "Stealthy",
-            "Stelene",
-            "Steward",
             "Stocky",
             "Strapping",
             "Streetwise",
-            "Stressful",
             "Striking",
             "Stunning",
             "Stupendous",
             "Sturdy",
             "Suave",
-            "Suctorial",
-            "Sudden",
-            "Sultry",
-            "Superstitious",
             "Surreptitious",
             "Swarthy",
         ],
@@ -1228,8 +1067,6 @@ ubuntu_names = {
             "Salamander",
             "Salmon",
             "Saola",
-            "Sasquatch",
-            "Satyr",
             "Scallop",
             "Scorpion",
             "Scorpionfish",
@@ -1250,10 +1087,7 @@ ubuntu_names = {
             "Sloth",
             "Snail",
             "Snake",
-            "Snake",
             "Snapper",
-            "Snapping-Turtle",
-            "Snow-Leopard",
             "Spaniel",
             "Sparrow",
             "Spider",
@@ -1263,12 +1097,11 @@ ubuntu_names = {
             "Stallion",
             "Starfish",
             "Stingray",
-            "Sukko",
-            "Suricata",
             "Suricate",
             "Swallow",
             "Swan",
             "Swordfish",
+            "Stegosaurus",
         ],
     },
     "t": {
@@ -1277,18 +1110,9 @@ ubuntu_names = {
             "Tactful",
             "Talented",
             "Tame",
-            "Tantric",
-            "Tangible",
             "Tangled",
-            "Tanked",
             "Tasteful",
             "Tasty",
-            "Taught",
-            "Teachable",
-            "Tedious",
-            "Teeming",
-            "Tempean",
-            "Temperamental",
             "Temperate",
             "Tenable",
             "Tenacious",
@@ -1298,7 +1122,6 @@ ubuntu_names = {
             "Therapeutic",
             "Thorough",
             "Thoughtful",
-            "Thrashing",
             "Thrifty",
             "Thrilled",
             "Thrilling",
@@ -1309,40 +1132,24 @@ ubuntu_names = {
             "Timely",
             "Timeless",
             "Tiny",
-            "Tipsy",
             "Tireless",
             "Tolerant",
-            "Touching",
             "Tough",
-            "Touted",
             "Trailblazing",
             "Tranquil",
-            "Transgendered",
             "Transcendent",
             "Transcendental",
-            "Transsexual",
-            "Transparent",
-            "Transpicuous",
-            "Traumatized",
             "Traveled",
             "Treasured",
             "Tremendous",
-            "Tretis",
-            "Tricky",
             "Trim",
             "Trippy",
             "Triumphant",
             "True",
             "Truculent",
-            "Trusted",
-            "Trustful",
             "Trustworthy",
-            "Trusty",
             "Truthful",
             "Twirling",
-            "Tweaky",
-            "Twitchy",
-            "Tympanic",
         ],
         "animals": [
             "Tahr",
@@ -1354,6 +1161,7 @@ ubuntu_names = {
             "Tarsier",
             "Tasmanian-Devil",
             "Tenrec",
+            "Tardigrade",
             "Termite",
             "Terrapin",
             "Terrier",
@@ -1364,77 +1172,63 @@ ubuntu_names = {
             "Tortoise",
             "Toucan",
             "Trogon",
-            "Troll",
             "Trout",
             "Tuatara",
             "Turkey",
             "Turtle",
-            "Tassie-Thylacine",
-            "Tazzy-Thylacine",
-            "Tesselated",
+            "Triceratops",
+            "Tyrannosaur",
+            "Titanosaur",
         ],
     },
     "u": {
         "adjectives": [
-            "Ubuntu",
-            "Ugly",
             "Ultimate",
-            "Unadulterated",
-            "Unapologetic",
             "Unassailable",
             "Unassuming",
             "Unbelievable",
-            "Ultrarelativistic",
-            "Unctuous",
             "Underrated",
-            "Underrepresented",
             "Understanding",
-            "Undulating",
             "Unplugged",
             "Unpretentious",
             "Unrated",
-            "Unrepentant",
-            "Unruly",
-            "Untamed",
-            "Untapped",
-            "Uppity",
-            "Undead",
             "Uproarious",
             "Ubiquitous",
             "Utopic",
         ],
         "animals": [
             "Uakari",
-            "Ubuntu",
-            "Uglybird",
-            "Utonagan",
+            "Uguisu",
+            "Uintathere",
+            "Umbrian",
             "Ungulate",
-            "Unicorn",
             "Urchin",
             "Urial",
             "Urubu",
             "Urukai",
-            "Uguisu",
-            "Umbrian",
-            "Uintathere",
+            "Utonagan",
         ],
     },
     "v": {
         "adjectives": [
             "Valiant",
+            "Valorous",
             "Vast",
             "Veracious",
+            "Verdant",
             "Versatile",
+            "Versed",
             "Veteran",
             "Vibrant",
             "Violent",
+            "Violet",
             "Viral",
             "Virtuoso",
-            "Vitriolic",
+            "Virtuous",
             "Vivacious",
             "Vivid",
-            "Vociferous",
-            "Volatile",
+            "Vocal",
+            "Vogue",
             "Voluptuous",
             "Voracious",
         ],
@@ -1445,25 +1239,33 @@ ubuntu_names = {
             "Vicuña",
             "Viper",
             "Vixen",
-            "Vizcacha",
             "Vole",
             "Vulture",
         ],
     },
     "w": {
         "adjectives": [
+            "Waggly",
             "Wandering",
             "Warm",
             "Warty",
-            "Western Tragopan",
+            "Wary",
+            "Washed",
+            "Watchful",
+            "Waterlogged",
+            "Whimsical",
+            "Whispering",
+            "White",
+            "Wholesome",
             "Wild",
             "Wily",
-            "Wimpy",
-            "Windy",
+            "Wise",
+            "Wistful",
             "Witty",
             "Wobbly",
             "Wonderful",
             "Woolly",
+            "Wry",
         ],
         "animals": [
             "Wallaby",
@@ -1471,15 +1273,16 @@ ubuntu_names = {
             "Warthog",
             "Wasp",
             "Weasel",
-            "Werewolf",
             "Weevil",
             "Whale",
+            "Whippet",
             "Wildebeest",
+            "Wildcat",
             "Wolf",
             "Wolverine",
             "Wombat",
             "Woodchuck",
-            "Woodpeck",
+            "Woodpecker",
             "Worm",
             "Wren",
             "Weka",
@@ -1488,26 +1291,19 @@ ubuntu_names = {
     "x": {
         "adjectives": [
             "Xanthic",
-            "Xenodochial",
-            "Xenolithic",
-            "Xenophobic",
+            "Xanthous",
             "Xenial",
             "Xeric",
-            "Xintillating",
-            "Xiphoid",
-            "Xylographic",
             "Xylophonic",
         ],
         "animals": [
             "Xebu",
             "Xenarthra",
-            "Xenomorph",
             "Xenoturbella",
             "Xenops",
             "Xerus",
             "Xiphias",
             "Xipho",
-            "X-ray fish",
             "Xue Bao",
             "Xoloitzcuintle",
             "Xólotl",
@@ -1516,15 +1312,22 @@ ubuntu_names = {
     "y": {
         "adjectives": [
             "Yakkity",
-            "Yammering",
+            "Yawning",
+            "Yearning",
+            "Yelling",
+            "Yellow",
             "Yelping",
-            "Yiffy",
-            "Yippity",
+            "Yodeling",
+            "Yogic",
             "Youthful",
             "Yummy",
-            "Yodeling",
+            "Yuppie",
+        ],
+        "animals": [
+            "Yaffle",
+            "Yak",
+            "Yellowjacket",
         ],
-        "animals": ["Yaffle", "Yak", "Yellowjacket", "Yeti"],
     },
     "z": {
         "adjectives": [
@@ -1534,8 +1337,15 @@ ubuntu_names = {
             "Zesty",
             "Zippy",
             "Zooming",
-            "Zarking",
+            "Zoophilic",
+        ],
+        "animals": [
+            "Zebra",
+            "Zebrafish",
+            "Zebu",
+            "Zooplankton",
+            "Zorilla",
+            "Zorse",
         ],
-        "animals": ["Zealot", "Zebra", "Zebrafish", "Zebu", "Zorilla", "Zorse"],
     },
 }
